@@ -11,11 +11,10 @@ sys.path.append(top_path)
 
 class SelectingFeatures():
 
-    def __init__(self, old_dir, standardization=None, balance=False):
-        self.data = self.data = pd.read_excel(old_dir,header=0)   # 第一行默认为表头，数据第一行必须有表头
-        self.save_dir = os.path.dirname(old_dir)       # 默认保存路径为原数据同一目录
-        self.x = self.data.iloc[:,:-1]
-        self.y = self.data.iloc[:, -1]
+    def __init__(self,x,y, standardization=None, balance=False):
+
+        self.x = x
+        self.y = y
 
         if balance:
             self.__balancing_sample()
@@ -54,7 +53,7 @@ class SelectingFeatures():
         from sklearn.feature_selection import VarianceThreshold
         vt = VarianceThreshold().fit(self.x,self.y)
         variances = vt.variances_
-        return self.save_weight('variances', variances)
+        return variances
 
     def filter_correlation(self,how='pearsonr'):
 
