@@ -2,6 +2,7 @@ import os
 import sys
 import importlib
 import shutil
+from tensorflow.keras import callbacks
 
 # 添加包的顶层目录
 top_path = os.path.abspath(__file__)
@@ -29,7 +30,7 @@ class GetBestModel():
         import config
 
         self.config = config
-        print(self.config.random_search_n_iter)
+
 
     def GetBestTradition(self,model,parameters,x,y):
         """
@@ -56,7 +57,7 @@ class GetBestModel():
         return best_model,best_params
 
 
-    def GetBestNNet(self,model_fun,x,y,**kwargs):
+    def GetBestNNet(self,model_fun,x_train,y_train,x_val,y_val,path_dir,**kwargs):
         """
         超参数列表已经在构建模型的时候内置到模型里面了，所以不用传入，这人是用keras-tuner调参的一个特性，
         也是与传统调参方法不同的地方。
@@ -67,21 +68,23 @@ class GetBestModel():
             objective=self.config.scoring,  # 优化目标
             max_trials=self.config.max_trials,
             executions_per_trial=self.config.executions_per_trial,
-            directory= model_fun.__name__ +'_dir',
-            project_name= model_fun.__name__ ,
+            directory=path_dir,
+            # project_name= model_fun.__name__ ,
         )
 
-        print(tuner.search_space_summary())
+        _callbacks = [
+            callbacks.EarlyStopping(patience=self.config.patience, min_delta=1e-3,monitor='val_accuracy')
+        ]
 
-        tuner.search(x, y,
+        tuner.search(x_train,y_train,
                      epochs=self.config.epochs_num,
+                     callbacks=_callbacks,
+                     # validation_data = (x_val,y_val)
                      )
+        
+       
 
-        print(tuner.search_space_summary())
-        print(tuner.results_summary())
-
-
-        return tuner.get_best_models(num_models=1), tuner.results_summary(num_trials=1)
+        return tuner.get_best_hyperparameters(num_trials=1)[0]
 
 
 
