@@ -14,6 +14,7 @@ def GetTraMandP(model_name):
         'max_depth': range(5, 25, 1),
         'max_features': ['auto', 'sqrt', 'log2'],
         'min_samples_split': range(2, 5, 1),
+        'random_state': [2021]
     }
 
     KNN_parameters = {
@@ -26,7 +27,8 @@ def GetTraMandP(model_name):
         'C': np.arange(1, 8, 0.2),
         'kernel': ['linear', 'poly', 'rbf', 'sigmoid'],
         'gamma': ['scale', 'auto'],
-        'degree': range(1, 11, 1)
+        'degree': range(1, 11, 1),
+        'random_state': [2021]
     }
 
     # 模型列表
@@ -41,3 +43,5 @@ def GetTraMandP(model_name):
 
     return models_dict[model_name],param_dict[model_name]
 
+
+
