@@ -3,7 +3,7 @@ import pandas as pd
 
 
 class Model(tf.keras.Model):
-    def __init__(self,initial_weigh,final_activation):
+    def __init__(self,initial_weigh,final_activation,drop_rate):
         super().__init__()
 
         self.layer_list = []
@@ -19,6 +19,9 @@ class Model(tf.keras.Model):
                 exec("self.layer{0} = tf.keras.layers.Dense(units=weights.shape[1],activation='{1}',kernel_initializer=kernel_initializer)".format(i,final_activation))
 
             exec('self.layer_list.append(self.layer{})'.format(i))
+            self.layer_list.append(tf.keras.layers.Dropout(drop_rate))
+
+        self.layer_list = self.layer_list[:-1]
 
     def call(self, x):
 
