@@ -15,8 +15,8 @@ class Model(tf.keras.Model):
         for i in range(hp.Int('num_layers', 1, 5)):
             hidden_layers.append(hp.Int('units_' + str(i),
                                             min_value=32,
-                                            max_value=512,
-                                            step=32))
+                                            max_value=400,
+                                            step=16))
 
         initial_weigh, error = w22n.Weights2HW(ori_weights, hidden_layers, False)
 
@@ -27,10 +27,15 @@ class Model(tf.keras.Model):
             if i != len(initial_weigh) -1:   #不是最后一层的时候，激活函数为rule
 
                 exec("self.layer{} = tf.keras.layers.Dense(units=weights.shape[1],activation='relu' ,kernel_initializer=kernel_initializer)".format(i))
+
             else:
                 exec("self.layer{0} = tf.keras.layers.Dense(units=weights.shape[1],activation='{1}',kernel_initializer=kernel_initializer)".format(i,final_activation))
 
             exec('self.layer_list.append(self.layer{})'.format(i))
+            self.layer_list.append(tf.keras.layers.Dropout(hp.Choice('drop_rate', values=[0.1,0.2,0.3,0.4])))
+
+        self.layer_list = self.layer_list[:-1]
+
 
     def build(self, input_shape):
         super(Model, self).build(input_shape)
